package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.gson.JsonObject;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaQrcode;
import com.huiju.estateagents.service.ITaQrcodeService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 二维码管理表 前端控制器
 * </p>
 *
 * @author fxf
 * @since 2020-05-20
 */
@RestController
@RequestMapping("/api")
public class TaQrcodeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaQrcodeController.class);

    @Autowired
    public ITaQrcodeService iTaQrcodeService;


    /**
     * 分页查询列表
     *
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/admin/listQrCode", method = RequestMethod.GET)
    public ResponseBean taQrcodeList(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                     @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                     String targetType, String targetName, Integer channelId, String buildingId,
                                     HttpServletRequest request) {
        logger.info("接收参数：targetType：{}，targetName：{}，channelId：{}，buildingId：{}",
                targetType, targetName, channelId, buildingId);
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TaQrcode> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaQrcode> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq(StringUtils.isNotBlank(targetType), "target_type", targetType);
            queryWrapper.eq(StringUtils.isNotBlank(targetName), "target_name", targetName);
            queryWrapper.eq(channelId != null, "channel_id", channelId);
            queryWrapper.eq(StringUtils.isNotBlank(buildingId), "buildingId", buildingId);
            queryWrapper.eq("org_id", getOrgId(request));
            queryWrapper.orderByDesc("create_date");

            IPage<TaQrcode> result = iTaQrcodeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taQrcodeList -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     *
     * @param taQrcode 实体对象
     * @return
     */
    @RequestMapping(value = "/admin/taQrcode", method = RequestMethod.POST)
    public ResponseBean taQrcodeAdd(@RequestBody TaQrcode taQrcode, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            taQrcode.setOrgId(getOrgId(request));
            taQrcode.setCreateUser(getUserId(request));
            taQrcode.setCreateDate(LocalDateTime.now());
            taQrcode.setStatus(CommConstant.STATUS_NORMAL);

            if (iTaQrcodeService.save(taQrcode)) {
                responseBean.addSuccess(taQrcode);
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taQrcodeAdd -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     *
     * @param id 实体ID
     */
    @ResponseBody
    @RequestMapping(value = "/taQrcode/{id}", method = RequestMethod.DELETE)
    public ResponseBean taQrcodeDelete(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaQrcodeService.removeById(id)) {
                responseBean.addSuccess("success");
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taQrcodeDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 批量删除
     */
    @ResponseBody
    @RequestMapping(value = "/admin/qrCode/batchDelete", method = RequestMethod.DELETE)
    public ResponseBean batchDelete(List<TaQrcode> taQrcodeList) {
        ResponseBean responseBean = new ResponseBean();
        try {

            taQrcodeList.stream().forEach((record) -> {
                record.setStatus(CommConstant.STATUS_DELETE);
            });

            responseBean.addSuccess(iTaQrcodeService.updateBatchById(taQrcodeList));

        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taQrcodeDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    /**
     * 修改对象
     *
     * @param id       实体ID
     * @param taQrcode 实体对象
     * @return
     */
    @RequestMapping(value = "/taQrcode/{id}", method = RequestMethod.PUT)
    public ResponseBean taQrcodeUpdate(@PathVariable Integer id,
                                       @RequestBody TaQrcode taQrcode) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaQrcodeService.updateById(taQrcode)) {
                responseBean.addSuccess(taQrcode);
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taQrcodeUpdate -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     *
     * @param id 实体ID
     */
    @RequestMapping(value = "/taQrcode/{id}", method = RequestMethod.GET)
    public ResponseBean taQrcodeGet(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaQrcodeService.getById(id));
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taQrcodeDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
